pilas.actores.aceituna

Package pilas :: Package actores :: Module aceituna |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.aceituna

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  import pilas
    10  from pilas.actores import Actor
    11
    12
    13 -class Aceituna(Actor):
    14      """ Representa una Aceituna.
    15      Tiene la capacidad de reir, burlarse, gritar y saltar.
    16
    17          .. image:: images/actores/aceituna.png
    18
    19      """
    20
    21 -    def __init__(self, x=0, y=0):
    22          """ Constructor de la Aceituna
    23
    24          :param x: Posición horizontal de la aceituna.
    25          :type x: int
    26          :param y: Posición vertical de la aceituna.
    27          :type y: int
    28          """
    29          self.cuadro_normal = pilas.imagenes.cargar("aceituna.png")
    30          self.cuadro_reir = pilas.imagenes.cargar("aceituna_risa.png")
    31          self.cuadro_burla = pilas.imagenes.cargar("aceituna_burla.png")
    32          self.cuadro_grita = pilas.imagenes.cargar("aceituna_grita.png")
    33
    34          Actor.__init__(self, x=x, y=y)
    35          self.imagen = self.cuadro_normal
    36          self.centro = ('centro', 'centro')
    37          self.radio_de_colision = 18
    38
    39 -    def normal(self):
    40          """ Establece la imagen de la aceituna a Normal. """
    41          self.imagen = self.cuadro_normal
    42
    43 -    def reir(self):
    44          """ Hace que la aceituna aparezca sonriendo."""
    45          self.imagen = self.cuadro_reir
    46
    47 -    def burlarse(self):
    48          """ Hace que la aceituna aparezca sacando la lengua. """
    49          self.imagen = self.cuadro_burla
    50
    51      burlar = burlarse
    52
    53 -    def gritar(self):
    54          """ Hace que la aceituna abra la boca. """
    55          self.imagen = self.cuadro_grita
    56
    57 -    def saltar(self):
    58          """ Hace que la aceituna salte y emita un sonido de 'boing'."""
    59          self.hacer(pilas.comportamientos.Saltar())
    60